@@ -1,12 +1,11 @@
-# -*- coding: utf-8 -*-
 """Resource view class containing all logic for creating, checking, and updating resource views."""
 import logging
 from os.path import join
-from typing import Optional, List, Any, Dict, Union
+from typing import Any, Dict, List, Optional, Union
 
 from hdx.utilities import is_valid_uuid
 
-from hdx.data.hdxobject import HDXObject, HDXError
+from hdx.data.hdxobject import HDXError, HDXObject
 from hdx.hdx_configuration import Configuration
 
 logger = logging.getLogger(__name__)
@@ -20,31 +19,34 @@ class ResourceView(HDXObject):
         configuration (Optional[Configuration]): HDX configuration. Defaults to global configuration.
     """
 
-    def __init__(self, initial_data=None, configuration=None):
-        # type: (Optional[Dict], Optional[Configuration]) -> None
+    def __init__(
+        self,
+        initial_data: Optional[Dict] = None,
+        configuration: Optional[Configuration] = None,
+    ) -> None:
         if not initial_data:
             initial_data = dict()
-        super(ResourceView, self).__init__(initial_data, configuration=configuration)
+        super().__init__(initial_data, configuration=configuration)
 
     @staticmethod
-    def actions():
-        # type: () -> Dict[str, str]
+    def actions() -> Dict[str, str]:
         """Dictionary of actions that can be performed on object
 
         Returns:
             Dict[str, str]: Dictionary of actions that can be performed on object
         """
         return {
-            'show': 'resource_view_show',
-            'update': 'resource_view_update',
-            'create': 'resource_view_create',
-            'delete': 'resource_view_delete',
-            'list': 'resource_view_list',
-            'reorder': 'resource_view_reorder'
+            "show": "resource_view_show",
+            "update": "resource_view_update",
+            "create": "resource_view_create",
+            "delete": "resource_view_delete",
+            "list": "resource_view_list",
+            "reorder": "resource_view_reorder",
         }
 
-    def update_from_yaml(self, path=join('config', 'hdx_resource_view_static.yml')):
-        # type: (str) -> None
+    def update_from_yaml(
+        self, path: str = join("config", "hdx_resource_view_static.yml")
+    ) -> None:
         """Update resource view metadata with static metadata from YAML file
 
         Args:
@@ -53,10 +55,11 @@ class ResourceView(HDXObject):
         Returns:
             None
         """
-        super(ResourceView, self).update_from_yaml(path)
+        super().update_from_yaml(path)
 
-    def update_from_json(self, path=join('config', 'hdx_resource_view_static.json')):
-        # type: (str) -> None
+    def update_from_json(
+        self, path: str = join("config", "hdx_resource_view_static.json")
+    ) -> None:
         """Update resource view metadata with static metadata from JSON file
 
         Args:
@@ -65,11 +68,12 @@ class ResourceView(HDXObject):
         Returns:
             None
         """
-        super(ResourceView, self).update_from_json(path)
+        super().update_from_json(path)
 
     @classmethod
-    def read_from_hdx(cls, identifier, configuration=None):
-        # type: (str, Optional[Configuration]) -> Optional['ResourceView']
+    def read_from_hdx(
+        cls, identifier: str, configuration: Optional[Configuration] = None
+    ) -> Optional["ResourceView"]:
         """Reads the resource view given by identifier from HDX and returns ResourceView object
 
         Args:
@@ -79,11 +83,12 @@ class ResourceView(HDXObject):
         Returns:
             Optional[ResourceView]: ResourceView object if successful read, None if not
         """
-        return cls._read_from_hdx_class('resource view', identifier, configuration)
+        return cls._read_from_hdx_class("resource view", identifier, configuration)
 
     @staticmethod
-    def get_all_for_resource(identifier, configuration=None):
-        # type: (str, Optional[Configuration]) -> List['ResourceView']
+    def get_all_for_resource(
+        identifier: str, configuration: Optional[Configuration] = None
+    ) -> List["ResourceView"]:
         """Read all resource views for a resource given by identifier from HDX and returns list of ResourceView objects
 
         Args:
@@ -95,16 +100,19 @@ class ResourceView(HDXObject):
         """
 
         resourceview = ResourceView(configuration=configuration)
-        success, result = resourceview._read_from_hdx('resource view', identifier, 'id', ResourceView.actions()['list'])
+        success, result = resourceview._read_from_hdx(
+            "resource view", identifier, "id", ResourceView.actions()["list"]
+        )
         resourceviews = list()
         if success:
             for resourceviewdict in result:
-                resourceview = ResourceView(resourceviewdict, configuration=configuration)
+                resourceview = ResourceView(
+                    resourceviewdict, configuration=configuration
+                )
                 resourceviews.append(resourceview)
         return resourceviews
 
-    def check_required_fields(self, ignore_fields=list()):
-        # type: (List[str]) -> None
+    def check_required_fields(self, ignore_fields: List[str] = list()) -> None:
         """Check that metadata for resource view is complete. The parameter ignore_fields should
         be set if required to any fields that should be ignored for the particular operation.
 
@@ -114,66 +122,61 @@ class ResourceView(HDXObject):
         Returns:
             None
         """
-        self._check_required_fields('resource view', ignore_fields)
+        self._check_required_fields("resource view", ignore_fields)
 
-    def _update_resource_view(self, log=False, **kwargs):
-        # type: (bool, Any) -> bool
+    def _update_resource_view(self, log: bool = False, **kwargs: Any) -> bool:
         """Check if resource view exists in HDX and if so, update resource view
 
         Returns:
             bool: True if updated and False if not
         """
         update = False
-        if 'id' in self.data and self._load_from_hdx('resource view', self.data['id']):
+        if "id" in self.data and self._load_from_hdx("resource view", self.data["id"]):
             update = True
         else:
-            if 'resource_id' in self.data:
-                resource_views = self.get_all_for_resource(self.data['resource_id'])
+            if "resource_id" in self.data:
+                resource_views = self.get_all_for_resource(self.data["resource_id"])
                 for resource_view in resource_views:
-                    if self.data['title'] == resource_view['title']:
+                    if self.data["title"] == resource_view["title"]:
                         self.old_data = self.data
                         self.data = resource_view.data
                         update = True
                         break
         if update:
             if log:
-                logger.warning('resource view exists. Updating %s' % self.data['id'])
-            self._merge_hdx_update('resource view', 'id', **kwargs)
+                logger.warning(f"resource view exists. Updating {self.data['id']}")
+            self._merge_hdx_update("resource view", "id", **kwargs)
         return update
 
-    def update_in_hdx(self, **kwargs):
-        # type: (Any) -> None
+    def update_in_hdx(self, **kwargs: Any) -> None:
         """Check if resource view exists in HDX and if so, update resource view
 
         Returns:
             None
         """
         if not self._update_resource_view(**kwargs):
-            raise HDXError('No existing resource view to update!')
+            raise HDXError("No existing resource view to update!")
 
-    def create_in_hdx(self, **kwargs):
-        # type: (Any) -> None
+    def create_in_hdx(self, **kwargs: Any) -> None:
         """Check if resource view exists in HDX and if so, update it, otherwise create resource view
 
         Returns:
             None
         """
-        if 'ignore_check' not in kwargs:  # allow ignoring of field checks
+        if "ignore_check" not in kwargs:  # allow ignoring of field checks
             self.check_required_fields()
         if not self._update_resource_view(log=True, **kwargs):
-            self._save_to_hdx('create', 'title')
+            self._save_to_hdx("create", "title")
 
-    def delete_from_hdx(self):
-        # type: () -> None
+    def delete_from_hdx(self) -> None:
         """Deletes a resource view from HDX.
 
         Returns:
             None
         """
-        self._delete_from_hdx('resource view', 'id')
+        self._delete_from_hdx("resource view", "id")
 
-    def copy(self, resource_view):
-        # type: (Union[ResourceView,Dict,str]) -> None
+    def copy(self, resource_view: Union["ResourceView", Dict, str]) -> None:
         """Copies all fields except id, resource_id and package_id from another resource view.
 
         Args:
@@ -184,10 +187,12 @@ class ResourceView(HDXObject):
         """
         if isinstance(resource_view, str):
             if is_valid_uuid(resource_view) is False:
-                raise HDXError('%s is not a valid resource view id!' % resource_view)
+                raise HDXError(f"{resource_view} is not a valid resource view id!")
             resource_view = ResourceView.read_from_hdx(resource_view)
-        if not isinstance(resource_view, dict) and not isinstance(resource_view, ResourceView):
-            raise HDXError('%s is not a valid resource view!' % resource_view)
+        if not isinstance(resource_view, dict) and not isinstance(
+            resource_view, ResourceView
+        ):
+            raise HDXError(f"{resource_view} is not a valid resource view!")
         for key in resource_view:
-            if key not in ('id', 'resource_id', 'package_id'):
-                self.data[key] = resource_view[key]
\ No newline at end of file
+            if key not in ("id", "resource_id", "package_id"):
+                self.data[key] = resource_view[key]
